@@ -5,7 +5,7 @@ use warnings;
 use Carp ();
 use Exporter 'import';
 
-our $VERISON = '0.16';
+our $VERISON = '0.17';
 our @EXPORT = grep { !/import|BEGIN|EXPORT/ && Win32::Unicode::Constant->can($_) } keys %Win32::Unicode::Constant::;
 
 sub NULL     () { "\x00" }
@@ -18,7 +18,7 @@ sub STD_INPUT_HANDLE      () { -10 }
 sub STD_OUTPUT_HANDLE     () { -11 }
 sub STD_ERROR_HANDLE      () { -12 }
 sub MAX_BUFFER_SIZE       () { 20000 }
-sub CONSOLE_OUTPUT_HANDLE () { +{7 => 1, 11 => 1} }
+sub CONSOLE_OUTPUT_HANDLE () { +{7  => 1, 11 => 1, 15 => 1} }
 sub CONSOLE_ERROR_HANDLE  () { +{11 => 1, 15 => 1} }
 
 # file attribute
